package sun.management.snmp.jvminstr;

import java.lang.management.MemoryType;
import com.sun.jmx.snmp.SnmpStatusException;
import java.util.Map;
import sun.management.snmp.util.JvmContextFactory;
import sun.management.snmp.util.MibLogger;
import sun.management.snmp.jvmmib.EnumJvmMemPoolCollectThreshdSupport;
import sun.management.snmp.jvmmib.EnumJvmMemPoolThreshdSupport;
import sun.management.snmp.jvmmib.EnumJvmMemPoolType;
import sun.management.snmp.jvmmib.EnumJvmMemPoolState;
import java.lang.management.MemoryPoolMXBean;
import java.lang.management.MemoryUsage;
import sun.management.snmp.jvmmib.JvmMemPoolEntryMBean;

public class JvmMemPoolEntryImpl implements JvmMemPoolEntryMBean
{
    protected final int jvmMemPoolIndex;
    static final String memoryTag = "jvmMemPoolEntry.getUsage";
    static final String peakMemoryTag = "jvmMemPoolEntry.getPeakUsage";
    static final String collectMemoryTag = "jvmMemPoolEntry.getCollectionUsage";
    static final MemoryUsage ZEROS;
    final String entryMemoryTag;
    final String entryPeakMemoryTag;
    final String entryCollectMemoryTag;
    final MemoryPoolMXBean pool;
    private long jvmMemPoolPeakReset;
    private static final EnumJvmMemPoolState JvmMemPoolStateValid;
    private static final EnumJvmMemPoolState JvmMemPoolStateInvalid;
    private static final EnumJvmMemPoolType EnumJvmMemPoolTypeHeap;
    private static final EnumJvmMemPoolType EnumJvmMemPoolTypeNonHeap;
    private static final EnumJvmMemPoolThreshdSupport EnumJvmMemPoolThreshdSupported;
    private static final EnumJvmMemPoolThreshdSupport EnumJvmMemPoolThreshdUnsupported;
    private static final EnumJvmMemPoolCollectThreshdSupport EnumJvmMemPoolCollectThreshdSupported;
    private static final EnumJvmMemPoolCollectThreshdSupport EnumJvmMemPoolCollectThreshdUnsupported;
    static final MibLogger log;
    
    MemoryUsage getMemoryUsage() {
        try {
            Map<JvmMemPoolEntryImpl, MemoryUsage> userData = JvmContextFactory.getUserData();
            if (userData != null) {
                MemoryUsage memoryUsage = (MemoryUsage)userData.get(this.entryMemoryTag);
                if (memoryUsage != null) {
                    JvmMemPoolEntryImpl.log.debug("getMemoryUsage", this.entryMemoryTag + " found in cache.");
                    return memoryUsage;
                }
                MemoryUsage memoryUsage2 = this.pool.getUsage();
                if (memoryUsage2 == null) {
                    memoryUsage2 = JvmMemPoolEntryImpl.ZEROS;
                }
                userData.put(this.entryMemoryTag, memoryUsage2);
                return memoryUsage2;
            }
            else {
                JvmMemPoolEntryImpl.log.trace("getMemoryUsage", "ERROR: should never come here!");
                return this.pool.getUsage();
            }
        }
        catch (RuntimeException obj) {
            JvmMemPoolEntryImpl.log.trace("getMemoryUsage", "Failed to get MemoryUsage: " + obj);
            JvmMemPoolEntryImpl.log.debug("getMemoryUsage", obj);
            throw obj;
        }
    }
    
    MemoryUsage getPeakMemoryUsage() {
        try {
            Map<JvmMemPoolEntryImpl, MemoryUsage> userData = JvmContextFactory.getUserData();
            if (userData != null) {
                MemoryUsage memoryUsage = (MemoryUsage)userData.get(this.entryPeakMemoryTag);
                if (memoryUsage != null) {
                    if (JvmMemPoolEntryImpl.log.isDebugOn()) {
                        JvmMemPoolEntryImpl.log.debug("getPeakMemoryUsage", this.entryPeakMemoryTag + " found in cache.");
                        return memoryUsage;
                    }
                    return memoryUsage;
                }
                else {
                    MemoryUsage memoryUsage2 = this.pool.getPeakUsage();
                    if (memoryUsage2 == null) {
                        memoryUsage2 = JvmMemPoolEntryImpl.ZEROS;
                    }
                    userData.put(this.entryPeakMemoryTag, memoryUsage2);
                    return memoryUsage2;
                }
            }
            else {
                JvmMemPoolEntryImpl.log.trace("getPeakMemoryUsage", "ERROR: should never come here!");
                return JvmMemPoolEntryImpl.ZEROS;
            }
        }
        catch (RuntimeException obj) {
            JvmMemPoolEntryImpl.log.trace("getPeakMemoryUsage", "Failed to get MemoryUsage: " + obj);
            JvmMemPoolEntryImpl.log.debug("getPeakMemoryUsage", obj);
            throw obj;
        }
    }
    
    MemoryUsage getCollectMemoryUsage() {
        try {
            Map<JvmMemPoolEntryImpl, MemoryUsage> userData = JvmContextFactory.getUserData();
            if (userData != null) {
                MemoryUsage memoryUsage = (MemoryUsage)userData.get(this.entryCollectMemoryTag);
                if (memoryUsage != null) {
                    if (JvmMemPoolEntryImpl.log.isDebugOn()) {
                        JvmMemPoolEntryImpl.log.debug("getCollectMemoryUsage", this.entryCollectMemoryTag + " found in cache.");
                        return memoryUsage;
                    }
                    return memoryUsage;
                }
                else {
                    MemoryUsage memoryUsage2 = this.pool.getCollectionUsage();
                    if (memoryUsage2 == null) {
                        memoryUsage2 = JvmMemPoolEntryImpl.ZEROS;
                    }
                    userData.put(this.entryCollectMemoryTag, memoryUsage2);
                    return memoryUsage2;
                }
            }
            else {
                JvmMemPoolEntryImpl.log.trace("getCollectMemoryUsage", "ERROR: should never come here!");
                return JvmMemPoolEntryImpl.ZEROS;
            }
        }
        catch (RuntimeException obj) {
            JvmMemPoolEntryImpl.log.trace("getPeakMemoryUsage", "Failed to get MemoryUsage: " + obj);
            JvmMemPoolEntryImpl.log.debug("getPeakMemoryUsage", obj);
            throw obj;
        }
    }
    
    public JvmMemPoolEntryImpl(MemoryPoolMXBean pool, int n) {
        this.jvmMemPoolPeakReset = 0L;
        this.pool = pool;
        this.jvmMemPoolIndex = n;
        this.entryMemoryTag = "jvmMemPoolEntry.getUsage." + n;
        this.entryPeakMemoryTag = "jvmMemPoolEntry.getPeakUsage." + n;
        this.entryCollectMemoryTag = "jvmMemPoolEntry.getCollectionUsage." + n;
    }
    
    public Long getJvmMemPoolMaxSize() throws SnmpStatusException {
        long max = this.getMemoryUsage().getMax();
        if (max > -1L) {
            return new Long(max);
        }
        return JvmMemoryImpl.Long0;
    }
    
    public Long getJvmMemPoolUsed() throws SnmpStatusException {
        long used = this.getMemoryUsage().getUsed();
        if (used > -1L) {
            return new Long(used);
        }
        return JvmMemoryImpl.Long0;
    }
    
    public Long getJvmMemPoolInitSize() throws SnmpStatusException {
        long init = this.getMemoryUsage().getInit();
        if (init > -1L) {
            return new Long(init);
        }
        return JvmMemoryImpl.Long0;
    }
    
    public Long getJvmMemPoolCommitted() throws SnmpStatusException {
        long committed = this.getMemoryUsage().getCommitted();
        if (committed > -1L) {
            return new Long(committed);
        }
        return JvmMemoryImpl.Long0;
    }
    
    public Long getJvmMemPoolPeakMaxSize() throws SnmpStatusException {
        long max = this.getPeakMemoryUsage().getMax();
        if (max > -1L) {
            return new Long(max);
        }
        return JvmMemoryImpl.Long0;
    }
    
    public Long getJvmMemPoolPeakUsed() throws SnmpStatusException {
        long used = this.getPeakMemoryUsage().getUsed();
        if (used > -1L) {
            return new Long(used);
        }
        return JvmMemoryImpl.Long0;
    }
    
    public Long getJvmMemPoolPeakCommitted() throws SnmpStatusException {
        long committed = this.getPeakMemoryUsage().getCommitted();
        if (committed > -1L) {
            return new Long(committed);
        }
        return JvmMemoryImpl.Long0;
    }
    
    public Long getJvmMemPoolCollectMaxSize() throws SnmpStatusException {
        long max = this.getCollectMemoryUsage().getMax();
        if (max > -1L) {
            return new Long(max);
        }
        return JvmMemoryImpl.Long0;
    }
    
    public Long getJvmMemPoolCollectUsed() throws SnmpStatusException {
        long used = this.getCollectMemoryUsage().getUsed();
        if (used > -1L) {
            return new Long(used);
        }
        return JvmMemoryImpl.Long0;
    }
    
    public Long getJvmMemPoolCollectCommitted() throws SnmpStatusException {
        long committed = this.getCollectMemoryUsage().getCommitted();
        if (committed > -1L) {
            return new Long(committed);
        }
        return JvmMemoryImpl.Long0;
    }
    
    public Long getJvmMemPoolThreshold() throws SnmpStatusException {
        if (!this.pool.isUsageThresholdSupported()) {
            return JvmMemoryImpl.Long0;
        }
        long usageThreshold = this.pool.getUsageThreshold();
        if (usageThreshold > -1L) {
            return new Long(usageThreshold);
        }
        return JvmMemoryImpl.Long0;
    }
    
    public void setJvmMemPoolThreshold(Long n) throws SnmpStatusException {
        long longValue = (long)n;
        if (longValue < 0L) {
            throw new SnmpStatusException(10);
        }
        this.pool.setUsageThreshold(longValue);
        return;
    }
    
    public void checkJvmMemPoolThreshold(Long n) throws SnmpStatusException {
        if (!this.pool.isUsageThresholdSupported()) {
            throw new SnmpStatusException(12);
        }
        if ((long)n < 0L) {
            throw new SnmpStatusException(10);
        }
        return;
    }
    
    public EnumJvmMemPoolThreshdSupport getJvmMemPoolThreshdSupport() throws SnmpStatusException {
        if (this.pool.isUsageThresholdSupported()) {
            return JvmMemPoolEntryImpl.EnumJvmMemPoolThreshdSupported;
        }
        return JvmMemPoolEntryImpl.EnumJvmMemPoolThreshdUnsupported;
    }
    
    public Long getJvmMemPoolThreshdCount() throws SnmpStatusException {
        if (!this.pool.isUsageThresholdSupported()) {
            return JvmMemoryImpl.Long0;
        }
        long usageThresholdCount = this.pool.getUsageThresholdCount();
        if (usageThresholdCount > -1L) {
            return new Long(usageThresholdCount);
        }
        return JvmMemoryImpl.Long0;
    }
    
    public Long getJvmMemPoolCollectThreshold() throws SnmpStatusException {
        if (!this.pool.isCollectionUsageThresholdSupported()) {
            return JvmMemoryImpl.Long0;
        }
        long collectionUsageThreshold = this.pool.getCollectionUsageThreshold();
        if (collectionUsageThreshold > -1L) {
            return new Long(collectionUsageThreshold);
        }
        return JvmMemoryImpl.Long0;
    }
    
    public void setJvmMemPoolCollectThreshold(Long n) throws SnmpStatusException {
        long longValue = (long)n;
        if (longValue < 0L) {
            throw new SnmpStatusException(10);
        }
        this.pool.setCollectionUsageThreshold(longValue);
        return;
    }
    
    public void checkJvmMemPoolCollectThreshold(Long n) throws SnmpStatusException {
        if (!this.pool.isCollectionUsageThresholdSupported()) {
            throw new SnmpStatusException(12);
        }
        if ((long)n < 0L) {
            throw new SnmpStatusException(10);
        }
        return;
    }
    
    public EnumJvmMemPoolCollectThreshdSupport getJvmMemPoolCollectThreshdSupport() throws SnmpStatusException {
        if (this.pool.isCollectionUsageThresholdSupported()) {
            return JvmMemPoolEntryImpl.EnumJvmMemPoolCollectThreshdSupported;
        }
        return JvmMemPoolEntryImpl.EnumJvmMemPoolCollectThreshdUnsupported;
    }
    
    public Long getJvmMemPoolCollectThreshdCount() throws SnmpStatusException {
        if (!this.pool.isCollectionUsageThresholdSupported()) {
            return JvmMemoryImpl.Long0;
        }
        long collectionUsageThresholdCount = this.pool.getCollectionUsageThresholdCount();
        if (collectionUsageThresholdCount > -1L) {
            return new Long(collectionUsageThresholdCount);
        }
        return JvmMemoryImpl.Long0;
    }
    
    public static EnumJvmMemPoolType jvmMemPoolType(MemoryType memoryType) throws SnmpStatusException {
        if (memoryType.equals(MemoryType.HEAP)) {
            return JvmMemPoolEntryImpl.EnumJvmMemPoolTypeHeap;
        }
        if (memoryType.equals(MemoryType.NON_HEAP)) {
            return JvmMemPoolEntryImpl.EnumJvmMemPoolTypeNonHeap;
        }
        throw new SnmpStatusException(10);
    }
    
    public EnumJvmMemPoolType getJvmMemPoolType() throws SnmpStatusException {
        return jvmMemPoolType(this.pool.getType());
    }
    
    public String getJvmMemPoolName() throws SnmpStatusException {
        return JVM_MANAGEMENT_MIB_IMPL.validJavaObjectNameTC(this.pool.getName());
    }
    
    public Integer getJvmMemPoolIndex() throws SnmpStatusException {
        return new Integer(this.jvmMemPoolIndex);
    }
    
    public EnumJvmMemPoolState getJvmMemPoolState() throws SnmpStatusException {
        if (this.pool.isValid()) {
            return JvmMemPoolEntryImpl.JvmMemPoolStateValid;
        }
        return JvmMemPoolEntryImpl.JvmMemPoolStateInvalid;
    }
    
    public synchronized Long getJvmMemPoolPeakReset() throws SnmpStatusException {
        return new Long(this.jvmMemPoolPeakReset);
    }
    
    public synchronized void setJvmMemPoolPeakReset(Long n) throws SnmpStatusException {
        if ((long)n > this.jvmMemPoolPeakReset) {
            long currentTimeMillis = System.currentTimeMillis();
            this.pool.resetPeakUsage();
            this.jvmMemPoolPeakReset = currentTimeMillis;
            JvmMemPoolEntryImpl.log.debug("setJvmMemPoolPeakReset", "jvmMemPoolPeakReset=" + currentTimeMillis);
        }
    }
    
    public void checkJvmMemPoolPeakReset(Long n) throws SnmpStatusException {
    }
    
    static {
        ZEROS = new MemoryUsage(0L, 0L, 0L, 0L);
        JvmMemPoolStateValid = new EnumJvmMemPoolState("valid");
        JvmMemPoolStateInvalid = new EnumJvmMemPoolState("invalid");
        EnumJvmMemPoolTypeHeap = new EnumJvmMemPoolType("heap");
        EnumJvmMemPoolTypeNonHeap = new EnumJvmMemPoolType("nonheap");
        EnumJvmMemPoolThreshdSupported = new EnumJvmMemPoolThreshdSupport("supported");
        EnumJvmMemPoolThreshdUnsupported = new EnumJvmMemPoolThreshdSupport("unsupported");
        EnumJvmMemPoolCollectThreshdSupported = new EnumJvmMemPoolCollectThreshdSupport("supported");
        EnumJvmMemPoolCollectThreshdUnsupported = new EnumJvmMemPoolCollectThreshdSupport("unsupported");
        log = new MibLogger(JvmMemPoolEntryImpl.class);
    }
}
